@@ -3,21 +3,6 @@ import pytest
 import xml.etree.ElementTree as ET
 
 
-SLE_11_SP4_BASE = [
-    'SLE11-SDK-SP4-Pool',
-    'SLE11-SDK-SP4-Updates',
-    'SLE11-SP4-Debuginfo-Pool',
-    'SLE11-SP4-Debuginfo-Updates',
-    'SLES11-SP4-Pool',
-    'SLES11-SP4-Updates'
-]
-
-SLE_11_SP4_MODULES = [
-    'SLE11-Public-Cloud-Module',
-    'SLE11-Security-Module',
-    'SLES11-Extras'
-]
-
 SLE_12_BASE = [
     'SLES12-Debuginfo-Pool',
     'SLES12-Debuginfo-Updates',
@@ -513,8 +498,32 @@ SLE_15_SP3_X86_64_MODULES = [
     repo.replace('SP2', 'SP3') for repo in SLE_15_SP2_X86_64_MODULES
 ]
 
+BASE_15_SP4 = [
+    repo.replace('SP3', 'SP4') for repo in BASE_15_SP3 \
+    if 'Python2' not in repo
+]
+BASE_15_SP4_SAP = [
+    repo.replace('SP3', 'SP4') for repo in BASE_15_SP3_SAP \
+    if 'Python2' not in repo
+]
+BASE_15_SP4_HPC = [
+    repo.replace('SP3', 'SP4') for repo in BASE_15_SP3_HPC \
+    if 'Python2' not in repo
+]
+SLE_15_SP4_X86_64_MODULES = [
+    repo.replace('SP3', 'SP4') for repo in SLE_15_SP3_X86_64_MODULES
+]
+
+PYTHON3_MODULE = [
+    'SLE-Module-Python3-15-SP4-Pool',
+    'SLE-Module-Python3-15-SP4-Updates'
+]
+
+BASE_15_SP4 += PYTHON3_MODULE
+BASE_15_SP4_SAP += PYTHON3_MODULE
+BASE_15_SP4_HPC += PYTHON3_MODULE
+
 SLES_REPOS = {
-    '11.4-X86_64': SLE_11_SP4_BASE + SLE_11_SP4_MODULES,
     '12-X86_64': SLE_12_BASE + SLE_12_MODULES,
     '12-X86_64-SAP': SLE_12_SAP + SLE_12_BASE + SLE_12_MODULES,
     '12-X86_64-HPC': SLE_12_BASE + SLE_12_MODULES,
@@ -539,24 +548,24 @@ SLES_REPOS = {
         SLE_12_SP5_SAP + SLE_12_SP5_BASE + SLE_12_SP5_MODULES,
     '12-SP5-X86_64-HPC': SLE_12_SP5_BASE + SLE_12_SP5_MODULES,
     '15-AARCH64': BASE_15,
-    '15-AARCH64-SAP': BASE_15_SAP,
     '15-X86_64': BASE_15 + SLE_15_X86_64_MODULES,
     '15-X86_64-SAP': BASE_15_SAP + SLE_15_X86_64_MODULES,
     '15-SP1-AARCH64': BASE_15_SP1,
-    '15-SP1-AARCH64-SAP': BASE_15_SP1_SAP,
     '15-SP1-X86_64': BASE_15_SP1 + SLE_15_SP1_X86_64_MODULES,
     '15-SP1-X86_64-SAP': BASE_15_SP1_SAP + SLE_15_SP1_X86_64_MODULES,
     '15-SP1-X86_64-HPC': BASE_15_SP1_HPC,
     '15-SP2-AARCH64': BASE_15_SP2,
-    '15-SP2-AARCH64-SAP': BASE_15_SP2_SAP,
     '15-SP2-X86_64': BASE_15_SP2 + SLE_15_SP2_X86_64_MODULES,
     '15-SP2-X86_64-SAP': BASE_15_SP2_SAP + SLE_15_SP2_X86_64_MODULES,
     '15-SP2-X86_64-HPC': BASE_15_SP2_HPC,
     '15-SP3-AARCH64': BASE_15_SP3,
-    '15-SP3-AARCH64-SAP': BASE_15_SP3_SAP,
     '15-SP3-X86_64': BASE_15_SP3 + SLE_15_SP3_X86_64_MODULES,
     '15-SP3-X86_64-SAP': BASE_15_SP3_SAP + SLE_15_SP3_X86_64_MODULES,
     '15-SP3-X86_64-HPC': BASE_15_SP3_HPC,
+    '15-SP4-AARCH64': BASE_15_SP4,
+    '15-SP4-X86_64': BASE_15_SP4 + SLE_15_SP4_X86_64_MODULES,
+    '15-SP4-X86_64-SAP': BASE_15_SP4_SAP + SLE_15_SP4_X86_64_MODULES,
+    '15-SP4-X86_64-HPC': BASE_15_SP4_HPC,
 }
 
 
