@@ -6,7 +6,8 @@ def test_sles_repos(
     get_release_value,
     get_sles_repos,
     get_baseproduct,
-    determine_architecture
+    determine_architecture,
+    is_sles_sapcal
 ):
     version = [get_release_value('VERSION'), determine_architecture()]
 
@@ -21,6 +22,12 @@ def test_sles_repos(
     missing_repos = []
     repos = get_sles_repos(version)
 
+    if is_sles_sapcal():
+        repos = [repo for repo in repos if 'Python2' not in repo]
+
+        if get_release_value('VERSION') == '12-SP3':
+            repos = [repo for repo in repos if 'HPC' not in repo]
+
     if not repos:
         pytest.fail(
             'No repos found for version {0}'.format(version)
